@@ -20,19 +20,30 @@ import (
 	"os"
 	"testing"
 
+	"go.uber.org/zap"
+	"knative.dev/pkg/logging"
+
 	"knative.dev/eventing/pkg/apis/eventing"
 
 	"knative.dev/pkg/configmap"
 	. "knative.dev/pkg/reconciler/testing"
 
+	// Fake injection client
+	_ "knative.dev/eventing/pkg/client/injection/client/fake"
 	// Fake injection informers
 	_ "knative.dev/eventing/pkg/client/injection/informers/messaging/v1/inmemorychannel/fake"
 )
 
 func TestNew(t *testing.T) {
-	ctx, _ := SetupFakeContext(t)
+	ctx, cancel, _ := SetupFakeContextWithCancel(t)
+	defer cancel()
+	// Replace test logger because the shutdown of the dispatcher may happen
+	// after the test ends, causing a data race on the t logger
+	ctx = logging.WithLogger(ctx, zap.NewNop().Sugar())
 
 	os.Setenv("SCOPE", eventing.ScopeCluster)
+	os.Setenv("POD_NAME", "testpod")
+	os.Setenv("CONTAINER_NAME", "testcontainer")
 	c := NewController(ctx, &configmap.InformedWatcher{})
 
 	if c == nil {
@@ -41,9 +52,15 @@ func TestNew(t *testing.T) {
 }
 
 func TestNewInNamespace(t *testing.T) {
-	ctx, _ := SetupFakeContext(t)
+	ctx, cancel, _ := SetupFakeContextWithCancel(t)
+	defer cancel()
+	// Replace test logger because the shutdown of the dispatcher may happen
+	// after the test ends, causing a data race on the t logger
+	ctx = logging.WithLogger(ctx, zap.NewNop().Sugar())
 
 	os.Setenv("SCOPE", eventing.ScopeNamespace)
+	os.Setenv("POD_NAME", "testpod")
+	os.Setenv("CONTAINER_NAME", "testcontainer")
 	c := NewController(ctx, &configmap.InformedWatcher{})
 
 	if c == nil {
